aboutsummaryrefslogtreecommitdiff
path: root/discord/abc.py
diff options
context:
space:
mode:
Diffstat (limited to 'discord/abc.py')
-rw-r--r--discord/abc.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/discord/abc.py b/discord/abc.py
index 3132ca73..88e4bd96 100644
--- a/discord/abc.py
+++ b/discord/abc.py
@@ -114,7 +114,7 @@ class User(Snowflake, Protocol):
The user's username.
discriminator: :class:`str`
The user's discriminator.
- avatar: :class:`Asset`
+ avatar: :class:`~discord.Asset`
The avatar asset the user has.
bot: :class:`bool`
If the user is a bot account.
@@ -634,7 +634,7 @@ class GuildChannel:
Deletes the channel.
You must have :attr:`~Permissions.manage_channels` permission to use this.
Parameters
-----------
@@ -678,7 +678,7 @@ class GuildChannel:
If the ``overwrite`` parameter is ``None``, then the permission
overwrites are deleted.
You must have the :attr:`~Permissions.manage_roles` permission to use this.
Examples
----------
@@ -860,7 +860,7 @@ class GuildChannel:
A rich interface to help move a channel relative to other channels.
- If exact position movement is required, :meth:`edit` should be used instead.
+ If exact position movement is required, ``edit`` should be used instead.
You must have the :attr:`~discord.Permissions.manage_channels` permission to
do this.
@@ -990,7 +990,7 @@ class GuildChannel:
Creates an instant invite from a text or voice channel.
You must have the :attr:`~Permissions.create_instant_invite` permission to
do this.
Parameters
@@ -1040,7 +1040,7 @@ class GuildChannel:
Returns a list of all active instant invites from this channel.
You must have :attr:`~Permissions.manage_channels` to get this information.
Raises
-------
@@ -1321,7 +1321,7 @@ class Messageable(Protocol):
def history(self, *, limit=100, before=None, after=None, around=None, oldest_first=None):
"""Returns an :class:`~discord.AsyncIterator` that enables receiving the destination's message history.
You must have :attr:`~Permissions.read_message_history` permissions to use this.
Examples
---------
@@ -634,7 +634,7 @@ class GuildChannel:
Deletes the channel.
- You must have :attr:`~Permissions.manage_channels` permission to use this.
+ You must have :attr:`~discord.Permissions.manage_channels` permission to use this.
Parameters
@@ -678,7 +678,7 @@ class GuildChannel:
If the ``overwrite`` parameter is ``None``, then the permission
overwrites are deleted.
- You must have the :attr:`~Permissions.manage_roles` permission to use this.
+ You must have the :attr:`~discord.Permissions.manage_roles` permission to use this.
Examples
@@ -990,7 +990,7 @@ class GuildChannel:
Creates an instant invite from a text or voice channel.
- You must have the :attr:`~Permissions.create_instant_invite` permission to
+ You must have the :attr:`~discord.Permissions.create_instant_invite` permission to
do this.
Parameters
@@ -1040,7 +1040,7 @@ class GuildChannel:
Returns a list of all active instant invites from this channel.
- You must have :attr:`~Permissions.manage_channels` to get this information.
+ You must have :attr:`~discord.Permissions.manage_channels` to get this information.
Raises
@@ -1321,7 +1321,7 @@ class Messageable(Protocol):
def history(self, *, limit=100, before=None, after=None, around=None, oldest_first=None):
"""Returns an :class:`~discord.AsyncIterator` that enables receiving the destination's message history.
- You must have :attr:`~Permissions.read_message_history` permissions to use this.
+ You must have :attr:`~discord.Permissions.read_message_history` permissions to use this.
Examples